@@ -14,9 +14,9 @@ use namespace::autoclean;
 with 'Net::Connector::Role';
 
 #------------------------------------------------------------------------------
-# 具体实现 _buildPrompt,设置设备脚本执行成功回显
+# 具体实现 _prompt,设置设备脚本执行成功回显
 #------------------------------------------------------------------------------
-sub _buildPrompt {
+sub _prompt {
   my $self   = shift;
   my $prompt = '>> Standalone ADC - (.*?)# ';
 
@@ -25,9 +25,9 @@ sub _buildPrompt {
 }
 
 #------------------------------------------------------------------------------
-# 具体实现 _buildCommands,设置抓取设备运行配置的脚本
+# 具体实现 _startupCommands,设置抓取设备启动配置的脚本
 #------------------------------------------------------------------------------
-sub _buildCommands {
+sub _startupCommands {
   my $self = shift;
 
   # my $commands = ["terminal length 0", "show running-config"];
@@ -36,9 +36,47 @@ sub _buildCommands {
 }
 
 #------------------------------------------------------------------------------
-# 具体实现 _buildErrorCode,设置命令下发错误码 -> 用于拦截配置下发
+# 具体实现 _runningCommands,设置抓取设备运行配置的脚本
 #------------------------------------------------------------------------------
-sub _buildErrorCode {
+sub _runningCommands {
+  my $self = shift;
+
+  # my $commands = ["terminal length 0", "show running-config"];
+  my $commands = [ "cfg/dump", "cd" ];
+  return $commands;
+}
+
+#------------------------------------------------------------------------------
+# 具体实现 _healthCheckCommands,设置抓取设备健康检查配置的脚本
+#------------------------------------------------------------------------------
+sub _healthCheckCommands {
+  my $self = shift;
+
+  # my $commands = ["terminal length 0", "show running-config"];
+  my $commands = [ "cfg/dump", "cd" ];
+  return $commands;
+}
+
+#------------------------------------------------------------------------------
+# 具体实现 truncateCommand，修正脚本下发后回显乱码
+#------------------------------------------------------------------------------
+sub truncateCommand {
+  my ( $self, $buff ) = @_;
+
+  # 字符串修正处理
+  $buff =~ s/\x1b\[\d+D\s+\x1b\[\d+D//g;
+  $buff =~ s/\r\n|\n+\n/\n/g;
+  $buff =~ s/^%.+$//mg;
+  $buff =~ s/^\s*$//mg;
+
+  # 返回修正数据
+  return $buff;
+}
+
+#------------------------------------------------------------------------------
+# 具体实现 _errorCodes,设置命令下发错误码 -> 用于拦截配置下发
+#------------------------------------------------------------------------------
+sub _errorCodes {
   my $self  = shift;
   my $codes = [
     'for a list of subcommands',
@@ -55,9 +93,9 @@ sub _buildErrorCode {
 }
 
 #------------------------------------------------------------------------------
-# 具体实现 _buildBufferCode,设置交互式执行脚本 -> 用于交互式下发配置
+# 具体实现 _bufferCodes,设置交互式执行脚本 -> 用于交互式下发配置
 #------------------------------------------------------------------------------
-sub _buildBufferCode {
+sub _bufferCodes {
   my $self    = shift;
   my %mapping = (
     more     => '--more--',
@@ -75,19 +113,16 @@ sub _buildBufferCode {
 # 具体实现 runCommands，编写进入特权模式、退出保存配置的逻辑
 #------------------------------------------------------------------------------
 sub runCommands {
-  my ( $self, $commands ) = @_;
-
-  # 用户传递的具体配置 | 需要先初始化配置
-  $self->setCommands($commands);
+  my ( $self, @commands ) = @_;
 
   # 配置下发前 | 切入配置模式
-  $self->addCommand('cfg');
+  unshift( @commands, "cfg" );
 
   # 完成配置后 | 报错具体配置
-  $self->pushCommand("save");
+  push( @commands, "save" );
 
   # 执行调度，配置批量下发
-  $self->execCommands( $self->commands->@* );
+  $self->execCommands(@commands);
 }
 
 __PACKAGE__->meta->make_immutable;
